@@ -87,6 +87,8 @@ sub downloadAndInstall {
         spawn(
             exec => [ 'getFromNpmCache', '-q', "$name:request-cache:$url" ],
             wait_child => 1,
+            no_check   => 1,
+            # XXX: Backwards compatibility, remove after dpkg 1.24.0.
             nocheck    => 1,
         );
         unless($?) {
@@ -138,6 +140,8 @@ sub downloadAndInstall {
         spawn(
             exec       => [ 'pkgjs-run', $postinstall ],
             wait_child => 1,
+            no_check   => 1,
+            # XXX: Backwards compatibility, remove after dpkg 1.24.0.
             nocheck    => 1,
             ( $dir ? ( chdir => $dir ) : () ),
         );
