@@ -28,6 +28,8 @@ sub uscanResult {
         to_string       => \$out,
         error_to_string => \$err,
         wait_child      => 1,
+        no_check        => 1,
+        # XXX: Backwards compatibility, remove after dpkg 1.24.0.
         nocheck         => 1,
         timeout         => 30,
     );
