@@ -449,6 +449,8 @@ sub _extLinks {
                 }
                 spawn(
                     exec => [ 'cp', '-rL', $_[0], "$dir/node_modules/$_[1]" ],
+                    no_check   => 1,
+                    # XXX: Backwards compatibility, remove after dpkg 1.24.0.
                     nocheck    => 1,
                     wait_child => 1,
                 );
@@ -490,6 +492,8 @@ sub _extLinks {
                             exec       => [ 'nodepath', '-B', $_ ],
                             wait_child => 1,
                             to_string  => \$src,
+                            no_check   => 1,
+                            # XXX: Backwards compatibility, remove after dpkg 1.24.0.
                             nocheck    => 1,
                         );
 
@@ -505,6 +509,8 @@ sub _extLinks {
                                     exec       => [ 'nodepath', '-B', $_ ],
                                     wait_child => 1,
                                     to_string  => \$src,
+                                    no_check   => 1,
+                                    # XXX: Backwards compatibility, remove after dpkg 1.24.0.
                                     nocheck    => 1,
                                 );
                                 if ( $? or not $src ) {
@@ -638,6 +644,8 @@ sub nodepath {
         exec       => [ 'nodepath', '-B', ( $WANTTS ? ('-t') : () ), $module ],
         to_string  => \$path,
         wait_child => 1,
+        no_check   => 1,
+        # XXX: Backwards compatibility, remove after dpkg 1.24.0.
         nocheck    => 1,
     );
     chomp $path;
